@@ -3,6 +3,7 @@ var globals_func =
     [ "b", "globals_func.html", null ],
     [ "c", "globals_func_c.html", null ],
     [ "d", "globals_func_d.html", null ],
+    [ "e", "globals_func_e.html", null ],
     [ "f", "globals_func_f.html", null ],
     [ "g", "globals_func_g.html", null ],
     [ "i", "globals_func_i.html", null ],
@@ -14,6 +15,5 @@ var globals_func =
     [ "s", "globals_func_s.html", null ],
     [ "t", "globals_func_t.html", null ],
     [ "u", "globals_func_u.html", null ],
-    [ "v", "globals_func_v.html", null ],
     [ "w", "globals_func_w.html", null ]
 ];
\ No newline at end of file
